from database.models.common.Model import Model
from sqlalchemy import Column, Integer, String
from database.services.DbService import Base


class MapEffectType(Model, Base):
    __tablename__ = 'map_effect_type'
    id = Column(Integer, primary_key=True)
    name = Column(String)

    def get_id(self):
        return self.id

    def set_name(self, value):
        self.name = value
        return self

    def get_name(self):
        return self.name
